@@ -328,7 +328,9 @@ get_user_programs()
 {
     ROVER_ENV(user_shell, SHELL)
     ROVER_ENV(user_pager, PAGER)
-    ROVER_ENV(user_editor, EDITOR)
+    ROVER_ENV(user_editor, VISUAL)
+    if (!user_editor)
+        ROVER_ENV(user_editor, EDITOR)
     ROVER_ENV(user_open, OPEN)
 }
 
@@ -495,16 +497,17 @@ update_view()
         } else {
             char *suffix, *suffixes = "BKMGTPEZY";
             off_t human_size = ESIZE(j) * 10;
-            int length = mbstowcs(NULL, ENAME(j), 0);
+            int length = mbstowcs(WBUF, ENAME(j), PATH_MAX);
+            int namecols = wcswidth(WBUF, length);
             for (suffix = suffixes; human_size >= 10240; suffix++)
                 human_size = (human_size + 512) / 1024;
             if (*suffix == 'B')
-                swprintf(WBUF, PATH_MAX, L"%s%*d %c", ENAME(j),
-                         (int) (COLS - length - 6),
+                swprintf(WBUF + length, PATH_MAX - length, L"%*d %c",
+                         (int) (COLS - namecols - 6),
                          (int) human_size / 10, *suffix);
             else
-                swprintf(WBUF, PATH_MAX, L"%s%*d.%d %c", ENAME(j),
-                         (int) (COLS - length - 8),
+                swprintf(WBUF + length, PATH_MAX - length, L"%*d.%d %c",
+                         (int) (COLS - namecols - 8),
                          (int) human_size / 10, (int) human_size % 10, *suffix);
         }
         mvwhline(rover.window, i + 1, 1, ' ', COLS - 2);
@@ -592,6 +595,10 @@ ls(Row **rowsp, uint8_t flags)
     if(!(dp = opendir("."))) return -1;
     n = -2; /* We don't want the entries "." and "..". */
     while (readdir(dp)) n++;
+    if (n == 0) {
+        closedir(dp);
+        return 0;
+    }
     rewinddir(dp);
     rows = malloc(n * sizeof *rows);
     i = 0;
@@ -1090,7 +1097,8 @@ main(int argc, char *argv[])
     init_marks(&rover.marks);
     cd(1);
     strcpy(CLIPBOARD, CWD);
-    strcat(CLIPBOARD, ENAME(ESEL));
+    if (rover.nfiles > 0)
+        strcat(CLIPBOARD, ENAME(ESEL));
     while (1) {
         ch = rover_getch();
         key = keyname(ch);
@@ -1455,14 +1463,20 @@ paste_path_fail:
             } else
                 message(RED, "No entries marked for deletion.");
         } else if (!strcmp(key, RVK_MARK_COPY)) {
-            if (rover.marks.nentries)
-                process_marked(adddir, cpyfile, NULL, "Copying", "Copied");
-            else
+            if (rover.marks.nentries) {
+                if (strcmp(CWD, rover.marks.dirpath))
+                    process_marked(adddir, cpyfile, NULL, "Copying", "Copied");
+                else
+                    message(RED, "Cannot copy to the same path.");
+            } else
                 message(RED, "No entries marked for copying.");
         } else if (!strcmp(key, RVK_MARK_MOVE)) {
-            if (rover.marks.nentries)
-                process_marked(adddir, movfile, deldir, "Moving", "Moved");
-            else
+            if (rover.marks.nentries) {
+                if (strcmp(CWD, rover.marks.dirpath))
+                    process_marked(adddir, movfile, deldir, "Moving", "Moved");
+                else
+                    message(RED, "Cannot move to the same path.");
+            } else
                 message(RED, "No entries marked for moving.");
         }
     }
